# Environments

This README provides an overview of the environment configurations defined in `environments/core.py`.

## Environment Class

The `Environment` class is defined to represent different deployment environments. It has the following attributes:

- `name`: The name of the environment (e.g., "development", "staging", "production")